Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AddressProvider ¶
type AddressProvider interface {
// RandomEmail is the function that provides randomization of email addresses.
// The input parameter of this function specifies the domain name while the output should be an email address
// that has the same domain as the input
RandomEmail(string) string
}
AddressProvider is an interface that provides email addresses
type DefaultRandomizer ¶
type DefaultRandomizer struct {
// Length is the length of the expected length of the email address before the @ part of the
// email address.
Length uint
}
DefaultRandomizer is the default randomizer used by soramail.
func (DefaultRandomizer) RandomEmail ¶
func (dr DefaultRandomizer) RandomEmail(domain string) string
Click to show internal directories.
Click to hide internal directories.